==> qt5-base-debuginfo-5.9.3-2.tar.xz: usr/src/debug/qt5-base-5.9.3-2/examples/widgets/draganddrop/draggabletext/.rcc/qrc_draggabletext.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.9.3
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/qt5-base/qt5-base-5.9.3-2.x86_64/src/qtbase-opensource-src-5.9.3/examples/widgets/draganddrop/draggabletext/words.txt
  0x0,0x0,0x0,0xf7,
  0x51,
  0x74,0xa,0x51,0x75,0x61,0x72,0x74,0x65,0x72,0x6c,0x79,0xa,0x69,0x73,0xa,0x61,
  0xa,0x70,0x61,0x70,0x65,0x72,0xa,0x62,0x61,0x73,0x65,0x64,0xa,0x6e,0x65,0x77,
  0x73,0x6c,0x65,0x74,0x74,0x65,0x72,0xa,0x65,0x78,0x63,0x6c,0x75,0x73,0x69,0x76,
  0x65,0x6c,0x79,0xa,0x61,0x76,0x61,0x69,0x6c,0x61,0x62,0x6c,0x65,0xa,0x74,0x6f,
  0xa,0x51,0x74,0xa,0x63,0x75,0x73,0x74,0x6f,0x6d,0x65,0x72,0x73,0xa,0x45,0x76,
  0x65,0x72,0x79,0xa,0x71,0x75,0x61,0x72,0x74,0x65,0x72,0xa,0x77,0x65,0xa,0x6d,
  0x61,0x69,0x6c,0xa,0x6f,0x75,0x74,0xa,0x61,0x6e,0xa,0x69,0x73,0x73,0x75,0x65,
  0xa,0x74,0x68,0x61,0x74,0xa,0x77,0x65,0xa,0x68,0x6f,0x70,0x65,0xa,0x77,0x69,
  0x6c,0x6c,0xa,0x62,0x72,0x69,0x6e,0x67,0xa,0x61,0x64,0x64,0x65,0x64,0xa,0x69,
  0x6e,0x73,0x69,0x67,0x68,0x74,0xa,0x61,0x6e,0x64,0xa,0x70,0x6c,0x65,0x61,0x73,
  0x75,0x72,0x65,0xa,0x74,0x6f,0xa,0x79,0x6f,0x75,0x72,0xa,0x51,0x74,0xa,0x70,
  0x72,0x6f,0x67,0x72,0x61,0x6d,0x6d,0x69,0x6e,0x67,0xa,0x77,0x69,0x74,0x68,0xa,
  0x68,0x69,0x67,0x68,0xa,0x71,0x75,0x61,0x6c,0x69,0x74,0x79,0xa,0x74,0x65,0x63,
  0x68,0x6e,0x69,0x63,0x61,0x6c,0xa,0x61,0x72,0x74,0x69,0x63,0x6c,0x65,0x73,0xa,
  0x77,0x72,0x69,0x74,0x74,0x65,0x6e,0xa,0x62,0x79,0xa,0x51,0x74,0xa,0x65,0x78,
  0x70,0x65,0x72,0x74,0x73,0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // dictionary
  0x0,0xa,
  0xb,0xb,0x17,0xd9,
  0x0,0x64,
  0x0,0x69,0x0,0x63,0x0,0x74,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,0x61,0x0,0x72,0x0,0x79,
    // words.txt
  0x0,0x9,
  0x8,0xb6,0xa7,0x34,
  0x0,0x77,
  0x0,0x6f,0x0,0x72,0x0,0x64,0x0,0x73,0x0,0x2e,0x0,0x74,0x0,0x78,0x0,0x74,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/dictionary
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/dictionary/words.txt
  0x0,0x0,0x0,0x1a,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x5f,0xc3,0x40,0xd9,0x80,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_draggabletext)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_draggabletext)()
{
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_draggabletext)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_draggabletext)()
{
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_draggabletext)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_draggabletext)(); }
   } dummy;
}

==> qt5-base-debuginfo-5.9.4-1.tar.xz: usr/src/debug/qt5-base-5.9.4-1/examples/widgets/draganddrop/draggabletext/.rcc/qrc_draggabletext.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.9.4
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/qt5-base/qt5-base-5.9.4-1.i686/src/qtbase-opensource-src-5.9.4/examples/widgets/draganddrop/draggabletext/words.txt
  0x0,0x0,0x0,0xf7,
  0x51,
  0x74,0xa,0x51,0x75,0x61,0x72,0x74,0x65,0x72,0x6c,0x79,0xa,0x69,0x73,0xa,0x61,
  0xa,0x70,0x61,0x70,0x65,0x72,0xa,0x62,0x61,0x73,0x65,0x64,0xa,0x6e,0x65,0x77,
  0x73,0x6c,0x65,0x74,0x74,0x65,0x72,0xa,0x65,0x78,0x63,0x6c,0x75,0x73,0x69,0x76,
  0x65,0x6c,0x79,0xa,0x61,0x76,0x61,0x69,0x6c,0x61,0x62,0x6c,0x65,0xa,0x74,0x6f,
  0xa,0x51,0x74,0xa,0x63,0x75,0x73,0x74,0x6f,0x6d,0x65,0x72,0x73,0xa,0x45,0x76,
  0x65,0x72,0x79,0xa,0x71,0x75,0x61,0x72,0x74,0x65,0x72,0xa,0x77,0x65,0xa,0x6d,
  0x61,0x69,0x6c,0xa,0x6f,0x75,0x74,0xa,0x61,0x6e,0xa,0x69,0x73,0x73,0x75,0x65,
  0xa,0x74,0x68,0x61,0x74,0xa,0x77,0x65,0xa,0x68,0x6f,0x70,0x65,0xa,0x77,0x69,
  0x6c,0x6c,0xa,0x62,0x72,0x69,0x6e,0x67,0xa,0x61,0x64,0x64,0x65,0x64,0xa,0x69,
  0x6e,0x73,0x69,0x67,0x68,0x74,0xa,0x61,0x6e,0x64,0xa,0x70,0x6c,0x65,0x61,0x73,
  0x75,0x72,0x65,0xa,0x74,0x6f,0xa,0x79,0x6f,0x75,0x72,0xa,0x51,0x74,0xa,0x70,
  0x72,0x6f,0x67,0x72,0x61,0x6d,0x6d,0x69,0x6e,0x67,0xa,0x77,0x69,0x74,0x68,0xa,
  0x68,0x69,0x67,0x68,0xa,0x71,0x75,0x61,0x6c,0x69,0x74,0x79,0xa,0x74,0x65,0x63,
  0x68,0x6e,0x69,0x63,0x61,0x6c,0xa,0x61,0x72,0x74,0x69,0x63,0x6c,0x65,0x73,0xa,
  0x77,0x72,0x69,0x74,0x74,0x65,0x6e,0xa,0x62,0x79,0xa,0x51,0x74,0xa,0x65,0x78,
  0x70,0x65,0x72,0x74,0x73,0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // dictionary
  0x0,0xa,
  0xb,0xb,0x17,0xd9,
  0x0,0x64,
  0x0,0x69,0x0,0x63,0x0,0x74,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,0x61,0x0,0x72,0x0,0x79,
    // words.txt
  0x0,0x9,
  0x8,0xb6,0xa7,0x34,
  0x0,0x77,
  0x0,0x6f,0x0,0x72,0x0,0x64,0x0,0x73,0x0,0x2e,0x0,0x74,0x0,0x78,0x0,0x74,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/dictionary
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/dictionary/words.txt
  0x0,0x0,0x0,0x1a,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x60,0xfd,0xbe,0xb8,0xd8,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_draggabletext)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_draggabletext)()
{
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_draggabletext)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_draggabletext)()
{
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_draggabletext)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_draggabletext)(); }
   } dummy;
}
